ffmpeg

package
v0.0.0-...-6c06906 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 25, 2026 License: Apache-2.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ExtractFrames

func ExtractFrames(filePath string, ffmpegPath string) ([]image.Image, error)

ExtractFrames extracts frames from a video file using FFmpeg and returns them as a slice of image.Image.

func LoadFrames

func LoadFrames(directory string) ([]image.Image, error)

LoadFrames loads all image files from the given directory and returns them as a slice of image.Image.

Types

This section is empty.

Jump to